#ifndef __776_H
#define __776_H

#ifdef MAIN
#define extern
#endif

#ifdef MAIN
#undef extern
#endif

#ifndef __STRINGS_H
#include <strings.h>
#endif

int MenuQuadri(int argc, char* argv[]);
int ImmissioneDichiarazioni(int argc, char* argv[]);
int SelezioneDichiarazioni(int argc, char* argv[]);
int ParametriStampa(int argc, char* argv[]);
int ParametriGenera(int argc, char* argv[]);
int Estinti(int argc, char* argv[]);

#endif // __776_H
