#include <xvt.h>
#include <checks.h>
#include "776.h"

#define usage   "Error - usage : %s -{0|1} [params]"

int main(int argc,char** argv)
{
  const int n = (argc > 1) ? atoi(argv[1]+1) : -1;
  switch(n)
  {
  case 0:
    MenuQuadri(argc,argv); break;
  case 1:
    ImmissioneDichiarazioni(argc,argv); break; 
  case 2:
    SelezioneDichiarazioni(argc, argv); break; 
  case 3:
    ParametriStampa(argc, argv); break;  
  case 4:
    ParametriGenera(argc, argv); break;  
  case 5:
    Estinti(argc, argv); break;  
  default:
    error_box(usage, argv[0]); break;
  }

  return n < 0;
}
